SoftInverseTripleBaseline
=========================

.. currentmodule:: pykeen.models

.. autoclass:: SoftInverseTripleBaseline
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SoftInverseTripleBaseline.score_h
      ~SoftInverseTripleBaseline.score_t

   .. rubric:: Methods Documentation

   .. automethod:: score_h
   .. automethod:: score_t
